#
# spec file for package sbsigntools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sbsigntools
Summary:        Canonical EFI binary signing tools
License:        GPL-3.0-only
Version:        0.9.5
Release:        1.5
URL:            http://git.kernel.org/pub/scm/linux/kernel/git/jejb/sbsigntools.git
Source:         %{name}-%{version}.tar.gz
BuildRequires:  binutils-devel
BuildRequires:  libuuid-devel
BuildRequires:  openssl-devel
%if 0%{?suse_version}
BuildRequires:  gnu-efi
BuildRequires:  pkg-config
%else
BuildRequires:  gnu-efi-devel
BuildRequires:  pkgconfig
%endif
BuildRequires:  automake
BuildRequires:  git
BuildRequires:  help2man

%description
This package installs tools which can cryptographically sign EFI
binaries and drivers.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
CFLAGS="%optflags -Wno-error=maybe-uninitialized"
%configure
%make_build

%check
%make_build check

%install
%make_install

%files
%license COPYING
%{_bindir}/sbattach
%{_bindir}/sbkeysync
%{_bindir}/sbsiglist
%{_bindir}/sbsign
%{_bindir}/sbvarsign
%{_bindir}/sbverify
%{_mandir}/man1/sbattach.1%{?ext_man}
%{_mandir}/man1/sbkeysync.1%{?ext_man}
%{_mandir}/man1/sbsiglist.1%{?ext_man}
%{_mandir}/man1/sbsign.1%{?ext_man}
%{_mandir}/man1/sbvarsign.1%{?ext_man}
%{_mandir}/man1/sbverify.1%{?ext_man}

%changelog
* Sun Apr  2 2023 bjorn.lie@gmail.com
- Update to version 0.9.5:
  * Fix openssl-3.0 issue involving ASN1 xxx_it
  * Add support for openssl-3
  * sbsigntool: add support for RISC-V 64-bit PE/COFF images
  * sbvarsign: do not include PKCS#7 attributes
  * sbkeysync: Don't ignore errors from insert_new_keys()
- Drop OpenSSL3.patch: Fixed upstream.
- Drop -Wno-error=deprecated-declarations, no longer needed.
- Add -Wno-error=maybe-uninitialized, needed when compiling with
  GCC 13.
- Use modern macros, list files explicitly, ensure we do not lose
  any.
* Sat Feb  4 2023 Marcus Meissner <meissner@suse.com>
- add -Wno-error=deprecated-declarations for openssl-3
- OpenSSL3.patch: patch from Ubuntu to fix openssl 3 build.
* Wed Apr 28 2021 rpm@fthiessen.de
- Update to version 0.9.4:
  * docs: add man page for sbkeysync
  * Fix errors on 32 bit
  * sbverify: refer to unused function
  * sbvarsign: remove unused global variable
  * Fix some openssl 1.1.0 deprecated functions
  * sbverify: fix verification with intermediate certificates
  * sbsign: allow for adding intermediate certificates
* Mon Apr 27 2020 Martin Loviska <mloviska@suse.com>
- Remove GROUP from spec file
* Fri Apr 24 2020 fvogt@suse.com
- Update to version 0.9.3:
  * Version 0.9.3
  * README: update git location and add mailing list information
  * sbvarsign: fix "EFI_VARIABLE_AUTHENTICATION_2.TimeStamp.Year" assignment
  * Fix PE/COFF checksum calculation
  * Version 0.9.2
  * src/image.c: remove alignment of regions
  * sbvarsign: use SignedData instead of PKCS7 for authenticated updates
  * Fix Fedora Build
  * Version 0.9.1
  * sbsign, sbvarsign: support engine based private keys
